<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="188"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Indstilling af brugerdefineret kommando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Skærm</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="191"/>
        <source>Use icon from theme or browse file</source>
        <translation>Brug ikon fra tema eller søg efter fil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="84"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Kør med &quot;bash -c&quot;</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
        <source>Select Font</source>
        <translation>Vælg skrifttype</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="221"/>
        <source>Use %1 to display command output</source>
        <translation>Brug %1 til at vise kommando uddata</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
        <source>Browse</source>
        <translation>Gennemse</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Roter automatisk når panelet er lodret</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="74"/>
        <source>echo Configure...</source>
        <translation>echo Indstil...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="77"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="288"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="305"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="322"/>
        <source>Command to run</source>
        <translation>Kør kommando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
        <source>Max Width</source>
        <translation>Max bredde</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
        <source>Repeat command after:</source>
        <translation>Gentag kommando efter:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="152"/>
        <source> second(s)</source>
        <translation> sekund(er)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="174"/>
        <source>Command outputs an image</source>
        <translation>Kommando udsender et billede</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source>Tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="272"/>
        <source>Mouse Commands</source>
        <translation>Muse kommandoer</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <source>Click</source>
        <translation>Klik</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="295"/>
        <source>Wheel Up</source>
        <translation>Hjul op</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="312"/>
        <source>Wheel Down</source>
        <translation>Hjul ned</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
        <source>Select Icon File</source>
        <translation>Vælg ikon fil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Billeder (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
